from pentest.command import JarvisCmd
import sys
__name__ = "nikto"


def main():
	args_config = {
		'passthrough_args': ['-o', '-h', '--help'],
		'output_args': [
			{
				'format': 'txt',
				'arg': '-o'
			}
		]
	}

	cmd = JarvisCmd(sys.argv)
	cmd.set_args_config(args_config)

	if '-host' not in cmd.args:
		cmd.run()

	try:
		target = cmd.args[cmd.args.index('-host') + 1]
	except IndexError:
		cmd.run()
	cmd.run(target)
