from pentest.command import JarvisCmd
import sys
__name__ = "airodump-ng"


def main():
	args_config = {
		'passthrough_args': ['-w', '-H'],
		'output_args': [
			{
				'format': None,
				'arg': '-w'
			}
		]
	}

	cmd = JarvisCmd(sys.argv)
	cmd.set_args_config(args_config)
	cmd.run()
