from pentest.command import JarvisCmd
import sys
__name__ = "crackmapexec"


def main():
	args_config = {
		'passthrough_args': ['-h', '--help'],
	}

	cmd = JarvisCmd(sys.argv)
	cmd.set_recordable(True)
	cmd.set_args_config(args_config)
	cmd.run()
